import { useState } from "preact/hooks";
import { HexColorPicker } from "react-colorful";

export const Color = ({ color: colorProp, onChange }) => {
    const [modalOpen, setModalOpen] = useState(false);
    const [color, setColor] = useState(colorProp);

    return (
        <>
            {modalOpen && (
                <ColorModal
                    color={color}
                    setModalOpen={setModalOpen}
                    onSave={setColor}
                ></ColorModal>
            )}
            <button
                class="change-color button is-rounded is-small"
                onClick={() => {
                    setModalOpen(true);
                }}
            >
                <span class="is-sr-only">Choose embed color</span>
                <i class="fas fa-eye-dropper"></i>
            </button>
        </>
    );
};

const ColorModal = ({ setModalOpen, color: colorProp, onSave }) => {
    const [color, setColor] = useState(colorProp);

    return (
        <div class="modal is-active" id="pickColorModal">
            <div
                class="modal-background"
                onClick={() => {
                    setModalOpen(false);
                }}
            ></div>
            <div class="modal-card">
                <header class="modal-card-head">
                    <label class="modal-card-title" for="colorInput">
                        Select Color
                    </label>
                    <button
                        class="delete close-modal"
                        aria-label="close"
                        onClick={() => {
                            setModalOpen(false);
                        }}
                    ></button>
                </header>
                <section class="modal-card-body">
                    <div class="colorpicker-container">
                        <HexColorPicker color={color} onChange={setColor}></HexColorPicker>
                    </div>
                    <br></br>
                    <input
                        class="input"
                        id="colorInput"
                        value={color}
                        onChange={(ev) => {
                            setColor(ev.currentTarget.value);
                        }}
                    ></input>
                </section>
                <footer class="modal-card-foot">
                    <button class="button is-success" onChange={onSave}>
                        Save
                    </button>
                    <button
                        class="button close-modal"
                        onClick={() => {
                            setModalOpen(false);
                        }}
                    >
                        Cancel
                    </button>
                </footer>
            </div>
            <button
                class="modal-close is-large close-modal"
                aria-label="close"
                onClick={() => {
                    setModalOpen(false);
                }}
            ></button>
        </div>
    );
};
