import { useState } from "preact/hooks";

function divmod(a: number, b: number) {
    return [Math.floor(a / b), a % b];
}

function secondsToHMS(seconds: number) {
    let hours: number, minutes: number;

    [minutes, seconds] = divmod(seconds, 60);
    [hours, minutes] = divmod(minutes, 60);

    return [hours, minutes, seconds];
}

export const IntervalSelector = ({ months: monthsProp, days: daysProp, seconds: secondsProp }) => {
    const [months, setMonths] = useState(monthsProp);
    const [days, setDays] = useState(daysProp);
    const [seconds, setSeconds] = useState(secondsProp);

    let [hours, minutes, secondsRem] = [0, 0, 0];
    if (seconds !== null) {
        [hours, minutes, secondsRem] = secondsToHMS(seconds);
    }

    return (
        <div class="control intervalSelector">
            <div class="input interval-group">
                <div class="interval-group-left">
                    <span class="no-break">
                        <label>
                            <span class="is-sr-only">Interval months</span>
                            <input
                                class="w2"
                                type="text"
                                pattern="\d*"
                                name="interval_months"
                                maxlength={2}
                                placeholder=""
                                value={months || ""}
                            ></input>{" "}
                            <span class="half-rem"></span> months, <span class="half-rem"></span>
                        </label>
                        <label>
                            <span class="is-sr-only">Interval days</span>
                            <input
                                class="w3"
                                type="text"
                                pattern="\d*"
                                name="interval_days"
                                maxlength={4}
                                placeholder=""
                                value={days || ""}
                            ></input>{" "}
                            <span class="half-rem"></span> days, <span class="half-rem"></span>
                        </label>
                    </span>
                    <span class="no-break">
                        <label>
                            <span class="is-sr-only">Interval hours</span>
                            <input
                                class="w2"
                                type="text"
                                pattern="\d*"
                                name="interval_hours"
                                maxlength={2}
                                placeholder="HH"
                                value={hours || ""}
                            ></input>
                            :
                        </label>
                        <label>
                            <span class="is-sr-only">Interval minutes</span>
                            <input
                                class="w2"
                                type="text"
                                pattern="\d*"
                                name="interval_minutes"
                                maxlength={2}
                                placeholder="MM"
                                value={minutes || ""}
                            ></input>
                            :
                        </label>
                        <label>
                            <span class="is-sr-only">Interval seconds</span>
                            <input
                                class="w2"
                                type="text"
                                pattern="\d*"
                                name="interval_seconds"
                                maxlength={2}
                                placeholder="SS"
                                value={secondsRem || ""}
                            ></input>
                        </label>
                    </span>
                </div>
                <button
                    class="clear"
                    onClick={() => {
                        setMonths(0);
                        setDays(0);
                        setSeconds(0);
                    }}
                >
                    <span class="is-sr-only">Clear interval</span>
                    <span class="icon">
                        <i class="fas fa-trash"></i>
                    </span>
                </button>
            </div>
        </div>
    );
};
